@@ -1,18 +1,18 @@
-# -*- coding: utf-8 -*-
 # Copyright 2004-2006 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2012 Christoph Reiter
 #           2013 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from quodlibet import _
 from quodlibet import app
 from quodlibet.plugins.events import EventPlugin
-from quodlibet.qltk import is_wayland, Icons
-from quodlibet.util import (is_unity, is_osx, is_plasma, is_enlightenment,
-                            print_exc, print_w, print_d)
+from quodlibet.qltk import Icons
+from quodlibet.util import (is_linux, is_osx, print_exc, print_w, print_d)
+from quodlibet.util.environment import dbus_name_owned
 
 from .prefs import Preferences
 from .systemtray import SystemTray
@@ -29,8 +29,8 @@ if is_osx():
 def get_indicator_impl():
     """Returns a BaseIndicator implementation depending on the environ"""
 
-    use_app_indicator = (is_unity() or is_wayland() or is_plasma() or
-                         is_enlightenment())
+    use_app_indicator = (
+        is_linux() and dbus_name_owned("org.kde.StatusNotifierWatcher"))
 
     print_d("use app indicator: %s" % use_app_indicator)
     if not use_app_indicator:
