@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2006 - Steve Frécinaux
 #            2016-17 - Nick Boultbee
 #
@@ -372,7 +371,7 @@ class PythonConsole(Gtk.ScrolledWindow):
         sys.stderr, self.stderr = self.stderr, sys.stderr
 
 
-class OutFile(object):
+class OutFile:
     """A fake output file object. It sends output to a TK test widget,
     and if asked for a file number, returns one set on instance creation"""
 
