@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2011-2018 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
@@ -8,7 +7,6 @@
 
 import os
 from urllib.parse import quote_plus
-from typing import Optional
 
 from gi.repository import Gtk
 
@@ -60,6 +58,8 @@ class WebsiteSearch(SongsMenuPlugin):
     PATTERNS_FILE = os.path.join(
         quodlibet.get_user_dir(), 'lists', 'searchsites')
 
+    _no_launch = False
+
     def __set_site(self, name):
         self.chosen_site = name
 
@@ -104,7 +104,7 @@ class WebsiteSearch(SongsMenuPlugin):
             self._url_pats = self.DEFAULT_URL_PATS
 
     def __init__(self, *args, **kwargs):
-        super(WebsiteSearch, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.chosen_site = None
         self._url_pats = []
         submenu = Gtk.Menu()
@@ -123,7 +123,7 @@ class WebsiteSearch(SongsMenuPlugin):
         else:
             self.set_sensitive(False)
 
-    def plugin_songs(self, songs, launch=True) -> bool:
+    def plugin_songs(self, songs):
         # Check this is a launch, not a configure
         if self.chosen_site:
             url_pat = self.get_url_pattern(self.chosen_site)
@@ -135,13 +135,13 @@ class WebsiteSearch(SongsMenuPlugin):
                         "Check your pattern?" % url_pat)
                 return False
             print_d("Got %d websites from %d songs" % (len(urls), len(songs)))
-            if launch:
+            if not self._no_launch:
                 for url in urls:
                     website(url)
         return True
 
 
-def website_for(pat: Pattern, song: AudioFile) -> Optional[str]:
+def website_for(pat, song):
     """Gets a utf-8 encoded string for a website from the given pattern"""
 
     # Generate a sanitised AudioFile; allow through most tags
