@@ -1,4 +1,4 @@
-# Copyright 2004-2013 Joe Wreschnig, Michael Urman, Niklas Janlert,
+# Copyright 2004-2020 Joe Wreschnig, Michael Urman, Niklas Janlert,
 #                     Steven Robertson, Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
@@ -8,12 +8,11 @@
 
 import mutagen.id3
 
-from quodlibet import config, const, print_d
+from quodlibet import config, const, print_w
 from quodlibet import util
 from quodlibet.util.iso639 import ISO_639_2
 from quodlibet.util.path import get_temp_cover_file
 from quodlibet.util.string import isascii
-
 from ._audio import AudioFile, translate_errors, AudioFileError
 from ._image import EmbeddedImage, APICType
 
@@ -23,14 +22,15 @@ def encoding_for(s):
     return 3 if isascii(s) else 1
 
 
-RG_KEYS = [
+RG_KEYS = {
     "replaygain_track_peak", "replaygain_track_gain",
     "replaygain_album_peak", "replaygain_album_gain",
-]
+}
 
 
 # ID3 is absolutely the worst thing ever.
 class ID3File(AudioFile):
+    supports_rating_and_play_count_in_file = True
 
     # http://www.unixgods.org/~tilo/ID3/docs/ID3_comparison.html
     # http://www.id3.org/id3v2.4.0-frames.txt
@@ -66,10 +66,11 @@ class ID3File(AudioFile):
            "TSOC": "composersort",
            "TMED": "media",
            "TCMP": "compilation",
+           "TKEY": "initialkey",
            # TLAN requires an ISO 639-2 language code, check manually
            #"TLAN": "language"
     }
-    SDI = dict([(v, k) for k, v in IDS.items()])
+    SDI = dict((v, k) for k, v in IDS.items())
 
     # At various times, information for this came from
     # http://musicbrainz.org/docs/specs/metadata_tags.html
@@ -92,7 +93,7 @@ class ID3File(AudioFile):
         u"ALBUMARTISTSORT": "albumartistsort",
         u"BARCODE": "barcode",
         }
-    PAM_XXXT = dict([(v, k) for k, v in TXXX_MAP.items()])
+    PAM_XXXT = dict((v, k) for k, v in TXXX_MAP.items())
 
     Kind = None
 
@@ -265,6 +266,13 @@ class ID3File(AudioFile):
                 return None
         return text
 
+    def has_rating_and_playcount_in_file(self, email):
+        with translate_errors():
+            audio = self.Kind(self['~filename'])
+        if audio.tags is None:
+            return False
+        return ("POPM:" + email) in audio.tags
+
     def write(self):
         with translate_errors():
             audio = self.Kind(self['~filename'])
@@ -304,8 +312,9 @@ class ID3File(AudioFile):
             else:
                 tag.add(Kind(encoding=enc, text=text))
 
-        dontwrite = ["genre", "comment", "musicbrainz_trackid", "lyrics"] \
-            + RG_KEYS + list(self.TXXX_MAP.values())
+        dont_write = (RG_KEYS
+                      | set(self.TXXX_MAP.values())
+                      | {"genre", "comment", "musicbrainz_trackid", "lyrics"})
 
         if "musicbrainz_trackid" in self.realkeys():
             f = mutagen.id3.UFID(
@@ -320,18 +329,19 @@ class ID3File(AudioFile):
             if all([lang in ISO_639_2 for lang in langs]):
                 # Save value(s) to TLAN tag. Guaranteed to be ASCII here
                 tag.add(mutagen.id3.TLAN(encoding=3, text=langs))
-                dontwrite.append("language")
+                dont_write.add("language")
             else:
-                print_d("Not using invalid language code '%s' in TLAN" %
-                        self["language"])
+                print_w(
+                    f"Not using invalid language {self['language']!r} in TLAN")
 
         # Filter out known keys, and ones set not to write [generically].
-        keys_to_write = filter(lambda k: not (k in self.SDI or k in dontwrite),
-                               self.realkeys())
+        dont_write |= self.SDI.keys()
+        keys_to_write = (k for k in self.realkeys()
+                         if k not in dont_write)
         for key in keys_to_write:
             enc = encoding_for(self[key])
             if key.startswith("performer:"):
-                mcl.people.append([key.split(":", 1)[1], self[key]])
+                mcl.people.append((key.split(":", 1)[1], self[key]))
                 continue
 
             f = mutagen.id3.TXXX(
@@ -378,7 +388,7 @@ class ID3File(AudioFile):
                 value = self[k]
                 tag.add(mutagen.id3.TXXX(encoding=encoding_for(value),
                                          text=value.split("\n"),
-                                         desc=k))
+                                         desc=k.upper()))
 
         # we shouldn't delete all, but we use unknown ones as fallback, so make
         # sure they don't come back after reloading
