@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2004-2006 Joe Wreschnig, Michael Urman, Niklas Janlert
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,6 +17,7 @@ class TrueAudioFile(ID3File):
 
     def _parse_info(self, info):
         self["~#length"] = info.length
+        self["~#samplerate"] = info.sample_rate
 
 loader = TrueAudioFile
 types = [TrueAudioFile]
