@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2005 Michael Urman, Joe Wreschnig
 #           2014, 2017 Nick Boultbee
 #
@@ -16,11 +15,10 @@ from quodlibet.plugins import PluginHandler
 from quodlibet.util.songwrapper import SongWrapper, ListWrapper
 from quodlibet.util.songwrapper import check_wrapper_changed
 from quodlibet.util import connect_obj
-from quodlibet.compat import listvalues
 from quodlibet.errorreport import errorhook
 
 
-class EventPlugin(object):
+class EventPlugin:
     """Plugins that run in the background and receive events.
 
     Event plugins, unlike other plugins, are instantiated on startup and
@@ -130,7 +128,7 @@ class EventPluginHandler(PluginHandler):
                 args[0] = SongWrapper(args[0])
             elif isinstance(args[0], (set, list)):
                 args[0] = ListWrapper(args[0])
-        for plugin in listvalues(self.__plugins):
+        for plugin in list(self.__plugins.values()):
             method_name = 'plugin_on_' + event.replace('-', '_')
             handler = getattr(plugin, method_name, None)
 
